Config

Struct Config 

pub struct Config {
    pub sink: Sink,
    pub path: Option<PathBuf>,
    pub format: Format,
    pub max_line_size: ByteSize,
    pub targets: FxHashMap<String, LoggingTargetConfig>,
}
Logger configuration.

It’s exported only for documentation purposes and cannot be created or received outside the dumper.

Fields

sink: Sink

Sink for the log output. By default logs are written to stdout.

path: Option<PathBuf>

Path to the log file, applicable only for Sink::File.

format: Format

Log format.

max_line_size: ByteSize

Size limit for each written log-line, in bytes. If size exceeds the limit, it will be truncated in the following order:

  1. Message with custom fields
  2. Meta-info (level, timestamp, …)
  3. Meta-fields (location, module)
targets: FxHashMap<String, LoggingTargetConfig>

Override log levels for specific targets. Useful to suppress noisy logs from dependencies.