pub struct ScopeFilter { /* private fields */ }Expand description
A tracing layer that filters events based on the current scope’s permissions and the configured targets.
For details see:
- Actor configuration for per-group logging levels and rate limits.
- The logger’s configuration for limiting targets.
It implements both Layer and Filter traits, so it can be used either
as a layer of a subscriber or as a filter of another layer.