pub struct Config {
pub sink: Sink,
pub path: Option<PathBuf>,
pub format: Format,
pub max_line_size: ByteSize,
pub targets: FxHashMap<String, LoggingTargetConfig>,
}Expand description
Logger configuration.
It’s exported only for documentation purposes and cannot be created or received outside the dumper.
Fields
sink: SinkSink for the log output. By default logs are written to stdout.
path: Option<PathBuf>Path to the log file, applicable only for Sink::File.
format: FormatLog format.
max_line_size: ByteSizeSize limit for each written log-line, in bytes. If size exceeds the limit, it will be truncated in the following order:
- Message with custom fields
- Meta-info (level, timestamp, …)
- Meta-fields (location, module)
targets: FxHashMap<String, LoggingTargetConfig>Override log levels for specific targets. Useful to suppress noisy logs from dependencies.